# Les contraintes topologiques dans Qualigéo

Une règle topologique définit les relations spatiales entre des entités vectorielles (points, polylignes, polygones) connectées ou adjacentes <a name="E0014E0015"></a>.

Le formulaire **caractéristiques de la contrainte topologique** permet de spécifier des règles topologiques qui lient les entités les unes aux autres. Par exemple, deux parcelles adjacentes ne peuvent pas se superposer et il ne peut y avoir de trous entre deux parcelles (autres que des voies non cadastrées).

La **<a name="kanchor49"></a>tesselation** met en avant les trous et chevauchements dans un jeu de données. La contrainte de tesselation [Laurini et Milleret-Raffort 1993] correspond à la partition totale d’un territoire par des polygones, sans espace ni chevauchement. La tesselation (ou mosaïque) est synonyme de couverture planaire. Les tuilages ou dallages sont des tesselations de motif régulier (rectangulaire en général).

La contrainte de tesselation de Qualigéo accepte que l’espace soit constituée d’éléments non connexes, totalement disjoints, comme des îles.

Dans Qualigéo, une contrainte de tesselation interdit donc le chevauchement de polygones ou la présence d’espaces fermées non remplis.
Les trous dans les polygones sont acceptés si ces trous sont remplis par un autre polygone.

<table> <col style="width: 353px;"></colgroup>

<tbody>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Cas de figure</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd">Contrôle dans Qualigéo</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep"><img src="..\_images/casfigure1.png"</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd" style="text-align: left;"> Tesselation (partition totale d’un territoire par des polygones, sans trou ni chevauchement) valide</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep"><img src="..\_images/casfigure2.png"></td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd" style="text-align: left;">Tesselation valide</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep"><img src="..\_images/casfigure3.png"></td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd" style="text-align: left;">Tesselation valide : espace constitué de plusieurs tesselations disjointes.</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep"><img src="..\_images/casfigure4.png"></td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd" style="text-align: left;">Tesselation non valide : création d’un espace vide. 1 erreur générée</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep"><img src="..\_images/casfigure5.png"></td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd" style="text-align: left;">Tesselation non valide : superposition. 1 erreur générée.</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowEnd_ColSep"><img src="..\_images/casfigure6.png"></td>

<td class="TableStyle_Basic_Body_0_0_RowEnd_ColEnd" style="text-align: left;">Tesselation non valide : 3 superpositions et 2 espaces vides. 5 erreurs générées.</td>

</tr>

</tbody>

</table>

## Attributs de regroupement et contrainte topologique

Le paramètre **Attributs de regroupement** permet de regrouper les entités à tester en les divisant en groupes en fonction des valeurs d’un attribut. Le contrôle est effectué sur les entités ayant les mêmes valeurs d’attribut de regroupement. Deux entités superposées ayant des valeurs d’attributs différentes ne génèrent donc pas d’erreur, le contrôle n’est pas effectué. Deux entités se chevauchant avec la même valeur d’attribut de regroupement produiront une erreur lors du contrôle.

![](../Ressources/Images/tesselation_regroupement1.png)

![](../Ressources/Images/tesselation_regroupement_286x231.png)

Dans l’exemple ci-dessus, si l’attribut de regroupement est TYPEZONE, alors la tesselation est valide et aucune erreur n’est générée. Inversement, si aucun attribut de regroupement n’est spécifié, deux erreurs sont générées (un espace vide et un chevauchement.)

**Règle de validation des erreurs**

Une règle de validation permet à l’application de valider des erreurs de tesselation. Ne sont considérés comme en erreur que les objets qui respectent la règle de validation.

Les exemples ci-dessous illustrent le cas de chevauchements et trous entre deux polygones. La règle de validation définie indique à Qualigéo qu’une erreur doit être générée si la superficie des espaces et chevauchements est inférieure à 1m².


![](../Ressources/Images/tesselation_regleValidation2.png)


Exemple :

<table style="width: 100%;margin-left: 0;margin-right: auto;mc-table-style: url(’../Resources/TableStyles/Basic.css’);" class="TableStyle_Basic" cellspacing="0"><colgroup><col> <col> <col> <col></colgroup>

<tbody>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep"> </td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Pas de règle de validation</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Règle de validation @Area()<10</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd">Règle de validation @Area()>10</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep"><img src="..\_images/tessealtion_regle_validite1_231x189.png"></td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Erreur E0014</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Erreur E0014</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd">Pas d’erreur</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep"><img src="..\_images/tessealtion_regle_validite2_223x145.png"></td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Erreur E0014</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Pas d’erreur</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd">Erreur E0014</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep"><img src="..\_images/tesselation_regle_validation3_198x104.png"></td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Erreur E0015</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColSep">Erreur E0015</td>

<td class="TableStyle_Basic_Body_0_0_RowSep_ColEnd">Pas d’erreur</td>

</tr>

<tr>

<td class="TableStyle_Basic_Body_0_0_RowEnd_ColSep"><img src="..\_images/tesselation_regle_validite4_223x107.png"></td>

<td class="TableStyle_Basic_Body_0_0_RowEnd_ColSep">Erreur E0015</td>

<td class="TableStyle_Basic_Body_0_0_RowEnd_ColSep">Pas d’erreur</td>

<td class="TableStyle_Basic_Body_0_0_RowEnd_ColEnd">Erreur E0015</td>

</tr>

</tbody>

</table>

La règle de validation correspond ainsi à une tolérance à partir de laquelle une erreur doit être retournée. Elle permet de passer outre des erreurs topologiques mineures ou au contraire des objets importants tels que des lacs ou la cour intérieure des immeubles.

La fonction à saisir dans la règle de validation peut contenir n’importe quelle formule exploitable par le Transformer ExpressionEvaluator de FME et renvoyant les valeurs 0 (faux) ou 1 (vrai).

 **Fonctions communément utilisées :**

* @Area(1) : renvoie la superficie de l’objet

* @Length(2,1) : renvoie le périmètre de l’objet

* @Value(attr) : renvoie la valeur de l’attribut "attr"

Attention, une erreur dans la formule risque de produire une erreur irrécupérable qui empêchera la réalisation du contrôle.

Toutes les fonctions disponibles sont décrites dans le document de référence : "FME functions and factories" de FME.
